@@ -86,7 +86,7 @@ import com.openexchange.mailfilter.exceptions.MailFilterExceptionCode;
  * the uncommented rules through this class.
  *
  * @author d7
- *
+ * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
 public final class SieveTextFilter {
 
@@ -234,6 +234,8 @@ public final class SieveTextFilter {
 
     private static final Pattern PATTERN = Pattern.compile("^" + FLAG_TAG + MATCH_STRING + SEPARATOR_REGEX + UNIQUE_ID + MATCH_STRING + SEPARATOR_REGEX + RULENAME_TAG + "(.*?)$");
 
+    private static final Pattern REQUIRE_PATTERN = Pattern.compile("(\"[a-z0-9\\.\\-]+\")+");
+
     // ------------------------------------------------------------------------------------------------------------------------------ //
 
     private final String username;
@@ -246,6 +248,14 @@ public final class SieveTextFilter {
         this.username = username;
     }
 
+    public static void main(String[] args) {
+        SieveTextFilter stf = new SieveTextFilter("skata");
+        String r = "# Generated by OX Sieve Bundle on Tue Mar 01 15:30:09 CET 2016\n" + "require [ \"date\" , \"vacation\" , \"relational\" , \"imap4flags\", \"fileinto\" ] ;\n\n"
+
+        + "## Flag: vacation|UniqueId:3|Rulename: vacation notice" + "if allof ( currentdate :value \"ge\" \"date\" \"2016-03-02\" , currentdate :value \"le\" \"date\" \"2016-03-09\" )" + " {";
+        stf.readRequire(r);
+    }
+
     public RuleListAndNextUid readScriptFromString(final String readFileToString) throws ParseException, SieveException, OXException {
         boolean errorsinscript = false;
         // The following line strips off the first line of the script
@@ -539,7 +549,7 @@ public final class SieveTextFilter {
             if (command instanceof IfStructureCommand) {
                 i += 2;
                 final IfStructureCommand ifstructure = (IfStructureCommand) command;
-                i += getActionCommandSize(ifstructure.getActioncommands());
+                i += getActionCommandSize(ifstructure.getActionCommands());
                 i++;
             } else {
                 i++;
@@ -952,4 +962,126 @@ public final class SieveTextFilter {
         }
         return retval;
     }
+
+    /**
+     * Rewrites the require part of the sieve script, retaining the previous and the current require sets.
+     * 
+     * @param writeback The writeback after the CRUD operation
+     * @param oldScript The old script before the CRUD operation
+     * @param sieveTextFilter The {@link SieveTextFilter}
+     * @return The new script with the rewritten 'require' part
+     */
+    public String rewriteRequire(String writeback, String oldScript) {
+        // Acquire both require lines
+        Set<String> require = readRequire(oldScript);
+        Set<String> writeBackRequire = readRequire(writeback);
+
+        // Merge require sets
+        Set<String> mergeRequire = new HashSet<String>();
+        mergeRequire.addAll(require);
+        mergeRequire.addAll(writeBackRequire);
+
+        String[] splitWriteBack = writeback.split("\r?\n");
+        // Script is empty, just return it
+        if (splitWriteBack.length < 2) {
+            return writeback;
+        }
+
+        // Assemble the merged require line
+        String requireLine = assembleRequire(mergeRequire);
+
+        // Inject the new requireLine to the new writeback
+        String[] writeBack = injectRequire(splitWriteBack, requireLine);
+
+        // Re-assemble the 'writeback' script from the array
+        return assembleWriteBack(writeBack);
+    }
+
+    /**
+     * Reads the require line from the specified script and returns it as a set with strings with '"' quotes
+     * 
+     * @param sieveScript The sieve script to read the require line from
+     * @return The set with the requires, or an empty set if no require line is present.
+     */
+    private Set<String> readRequire(String sieveScript) {
+        String[] split = sieveScript.split("\r?\n");
+        // The require part is always located in line 2 of the script, i.e. the 1st element of the array
+        if (split.length < 2 || !split[1].startsWith("require")) {
+            return Collections.emptySet();
+        }
+
+        String require = split[1];
+        final Matcher matcher = REQUIRE_PATTERN.matcher(require);
+        Set<String> requires = new HashSet<String>();
+        while (matcher.find()) {
+            requires.add(matcher.group());
+        }
+        return requires;
+    }
+
+    /**
+     * Assemble the require line
+     * 
+     * @param require The require set
+     * @return The require line as a string, or an empty string if the specified set is empty
+     */
+    private String assembleRequire(Set<String> require) {
+        if (require.isEmpty()) {
+            return "";
+        }
+
+        StringBuilder builder = new StringBuilder();
+        builder.append("require");
+        builder.append(" [ ");
+        for (String req : require) {
+            builder.append(req).append(" , ");
+        }
+        builder.setLength(builder.length() - 2);
+        builder.append("];");
+
+        return builder.toString();
+    }
+
+    /**
+     * Injects the specified require line to the specified split write back string array
+     * 
+     * @param splitWriteBack The split write back string array
+     * @param requireLine The require line
+     * @return The new writeback
+     */
+    private String[] injectRequire(String[] splitWriteBack, final String requireLine) {
+        // The require part is always located in line 2 of the script, i.e. the 1st element of the array
+        String requireSlice = splitWriteBack[1];
+        String[] writeBack;
+        if (requireSlice.startsWith("require")) {
+            // If the require line exists replace
+            splitWriteBack[1] = requireLine;
+            writeBack = splitWriteBack;
+        } else {
+            // Or add. Create a new array with size equals to the previous array + 2, to accommodate the require line plus an empty line 
+            writeBack = new String[splitWriteBack.length + 2];
+            // The top comment line
+            writeBack[0] = splitWriteBack[0];
+            // The require part
+            writeBack[1] = requireLine;
+            // empty line
+            writeBack[2] = "";
+            System.arraycopy(splitWriteBack, 1, writeBack, 3, splitWriteBack.length - 1);
+        }
+        return writeBack;
+    }
+
+    /**
+     * Re-assemble the 'writeback' script from the array
+     * 
+     * @param writeback
+     * @return
+     */
+    private String assembleWriteBack(String[] writeback) {
+        StringBuilder builder = new StringBuilder();
+        for (String swb : writeback) {
+            builder.append(swb).append(CRLF);
+        }
+        return builder.toString();
+    }
 }
