@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -154,7 +154,8 @@ public class Visitor implements SieveParserVisitor {
         ((List<OwnType>) data).add(new OwnType(new StringBuilder((this.inblock ? "    " : "") + node.getName() + " "), node.getCoordinate().getStartLineNumber()));
         final List<OwnType> visitChildren = (List<OwnType>) visitChildren(node, data);
         final StringBuilder output = visitChildren.get(visitChildren.size() - 1).getOutput();
-        if (output.charAt(output.length() - 3) != '}') {
+        // Consider variables in form of ${variable}
+        if ((output.charAt(output.length() - 3) == '}' && output.charAt(output.length() - 2) == '"') || output.charAt(output.length() - 3) != '}') {
             output.append(node.getLastToken());
         }
         return visitChildren;
