@@ -56,6 +56,7 @@ import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -163,6 +164,37 @@ public final class MailFilterServiceImpl implements MailFilterService {
         useSIEVEResponseCodes = Boolean.parseBoolean(config.getProperty(MailFilterProperties.Values.USE_SIEVE_RESPONSE_CODES.property));
     }
 
+    /**
+     * Closes given <tt>SieveHandler</tt> instance
+     *
+     * @param sieveHandler The <tt>SieveHandler</tt> instance to close
+     * @throws OXException If closing fails
+     */
+    private void closeSieveHandler(SieveHandler sieveHandler) throws OXException {
+        if (null != sieveHandler) {
+            try {
+                sieveHandler.close();
+            } catch (UnsupportedEncodingException e) {
+                throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
+            } catch (IOException e) {
+                throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
+            }
+        }
+    }
+
+    /**
+     * Gets the active Sieve script or an empty string if no active script is available
+     * <p>
+     * <b>Must only be called when holding lock!</b>
+     *
+     * @param sieveHandler The Sieve handler to use
+     * @return The action Siege script or an empty string
+     */
+    private String getScript(SieveHandler sieveHandler) throws OXSieveHandlerException, UnsupportedEncodingException, IOException {
+        String activeScript = sieveHandler.getActiveScript();
+        return null != activeScript ? sieveHandler.getScript(activeScript) : "";
+    }
+
     @Override
     public final int createFilterRule(Credentials credentials, Rule rule) throws OXException {
         Object lock = lockFor(credentials);
@@ -192,8 +224,8 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 changeIncomingVacationRule(rule);
 
                 int nextuid = insertIntoPosition(rule, rules, clientrulesandrequire);
-
                 String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 LOGGER.debug("The following sieve script will be written:\n{}", writeback);
                 writeScript(sieveHandler, activeScript, writeback);
 
@@ -209,15 +241,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.handleSieveException(e);
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -237,7 +261,9 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 }
 
                 String script = fixParsingError(sieveHandler.getScript(activeScript));
+
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
+
                 ClientRulesAndRequire clientRulesAndReq = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
                 RuleAndPosition rightRule = getRightRuleForUniqueId(clientRulesAndReq.getRules(), uid);
                 changeIncomingVacationRule(rightRule.rule);
@@ -248,6 +274,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
                     clientRulesAndReq.getRules().add(rule.getPosition(), rule);
                 }
                 String writeback = sieveTextFilter.writeback(clientRulesAndReq, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 LOGGER.debug("The following sieve script will be written:\n{}", writeback);
 
                 writeScript(sieveHandler, activeScript, writeback);
@@ -260,15 +287,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -279,7 +298,6 @@ public final class MailFilterServiceImpl implements MailFilterService {
         synchronized (lock) {
             SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
-
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
 
@@ -294,11 +312,13 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
                 List<Rule> rules = clientrulesandrequire.getRules();
                 RuleAndPosition deletedrule = getRightRuleForUniqueId(rules, uid);
-                if(deletedrule == null) {
+                if (deletedrule == null) {
                     throw MailFilterExceptionCode.BAD_POSITION.create(uid);
                 }
                 rules.remove(deletedrule.position);
+
                 String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 writeScript(sieveHandler, activeScript, writeback);
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
@@ -311,15 +331,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.handleSieveException(e);
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -341,6 +353,8 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
+            } finally {
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -352,8 +366,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String activeScript = sieveHandler.getActiveScript();
-                return (null != activeScript) ? sieveHandler.getScript(activeScript) : "";
+                return getScript(sieveHandler);
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (IOException e) {
@@ -365,15 +378,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (RuntimeException re) {
                 throw MailFilterExceptionCode.PROBLEM.create(re, re.getMessage());
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -390,14 +395,17 @@ public final class MailFilterServiceImpl implements MailFilterService {
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String activeScript = sieveHandler.getActiveScript();
-                String script = null != activeScript ? sieveHandler.getScript(activeScript) : "";
+                String script = getScript(sieveHandler);
                 LOGGER.debug("The following sieve script will be parsed:\n{}", script);
                 SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
+                removeErroneusRules(rules);
+
                 ClientRulesAndRequire clientrulesandrequire = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), flag.getFlag(), rules.isError());
                 List<Rule> clientRules = clientrulesandrequire.getRules();
                 changeOutgoingVacationRule(clientRules);
+                removeNestedRules(clientRules);
+
                 return clientRules;
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
@@ -410,15 +418,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -430,17 +430,20 @@ public final class MailFilterServiceImpl implements MailFilterService {
             SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
             try {
                 handlerConnect(sieveHandler, credentials.getSubject());
-                String activeScript = sieveHandler.getActiveScript();
-                String script = null != activeScript ? sieveHandler.getScript(activeScript) : "";
+                String script = getScript(sieveHandler);
                 LOGGER.debug("The following sieve script will be parsed:\n{}", script);
                 SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
+                removeErroneusRules(rules);
+
                 ClientRulesAndRequire splittedRules = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
 
                 if (splittedRules.getFlaggedRules() != null) {
                     return exclude(splittedRules.getFlaggedRules(), exclusionFlags);
                 }
-                return splittedRules.getRules();
+                List<Rule> splitRules = splittedRules.getRules();
+                removeNestedRules(splitRules);
+                return splitRules;
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
             } catch (ParseException e) {
@@ -452,15 +455,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -490,6 +485,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
                     }
 
                     String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
+                    writeback = sieveTextFilter.rewriteRequire(writeback, script);
                     writeScript(sieveHandler, activeScript, writeback);
                 } else {
                     throw MailFilterExceptionCode.NO_ACTIVE_SCRIPT.create();
@@ -505,15 +501,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -535,6 +523,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
                 String script = fixParsingError(sieveHandler.getScript(activeScript));
                 RuleListAndNextUid rules = sieveTextFilter.readScriptFromString(script);
+
                 ClientRulesAndRequire clientrulesandrequire = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
                 List<Rule> clientrules = clientrulesandrequire.getRules();
                 RuleAndPosition rightRule = getRightRuleForUniqueId(clientrules, uid);
@@ -556,15 +545,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.handleSieveException(e);
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -581,15 +562,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (OXSieveHandlerException e) {
                 throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
             } finally {
-                if (null != sieveHandler) {
-                    try {
-                        sieveHandler.close();
-                    } catch (UnsupportedEncodingException e) {
-                        throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
-                    } catch (IOException e) {
-                        throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e);
-                    }
-                }
+                closeSieveHandler(sieveHandler);
             }
         }
     }
@@ -599,7 +572,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
     private List<Rule> exclude(Map<String, List<Rule>> flagged, List<FilterType> exclusionFlags) {
         List<Rule> ret = new ArrayList<Rule>();
         for (FilterType flag : exclusionFlags) {
-            flagged.remove(flag);
+            flagged.remove(flag.getFlag());
         }
         for (List<Rule> l : flagged.values()) {
             ret.addAll(l);
@@ -607,6 +580,56 @@ public final class MailFilterServiceImpl implements MailFilterService {
         return ret;
     }
 
+    /**
+     * Removes the erroneous rules from the list
+     *
+     * @param rules rule list
+     */
+    private void removeErroneusRules(RuleListAndNextUid rules) {
+        if (rules.isError()) {
+            Iterator<Rule> ruleIter = rules.getRulelist().iterator();
+            while (ruleIter.hasNext()) {
+                Rule rule = ruleIter.next();
+                if (!Strings.isEmpty(rule.getErrormsg())) {
+                    ruleIter.remove();
+                }
+            }
+        }
+    }
+
+    /**
+     * Removes any nested rules from the specified Rule list
+     *
+     * @param rules The rule list
+     */
+    private void removeNestedRules(List<Rule> rules) {
+        Iterator<Rule> iterator = rules.iterator();
+        while (iterator.hasNext()) {
+            Rule rule = iterator.next();
+            IfCommand ifCommand = rule.getIfCommand();
+            List<?> actionCommands = ifCommand.getActionCommands();
+            if (containsNestedRule(actionCommands)) {
+                iterator.remove();
+            }
+        }
+    }
+
+    /**
+     * Checks if the specified list of commands contains a rule
+     *
+     * @param commands The list of commands
+     * @return true if at least one of the commands is a rule; false otherwise
+     */
+    private boolean containsNestedRule(List<?> commands) {
+        for (Object o : commands) {
+            if (o instanceof Rule) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     /**
      * Change a vacation rule
      *
@@ -670,7 +693,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
                         }
                     } else if (Commands.ALLOF.equals(testcommand.getCommand())) {
                         // In this case we find "our" rule at the first place
-                        List<TestCommand> testcommands = testcommand.getTestcommands();
+                        List<TestCommand> testcommands = testcommand.getTestCommands();
                         if (null != testcommands && testcommands.size() > 1) {
                             TestCommand testCommand2 = testcommands.get(0);
                             if (checkOwnVacation(testCommand2.getArguments())) {
@@ -692,6 +715,12 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
     /**
      * Check own vacation
+     * <<<<<<< HEAD
+     *
+     * ||||||| parent of 93f30cc... Fix for bug 48832: Don't write a completely empty sieve script when purging. Instead write only a comment line
+     * =======
+     * 
+     * >>>>>>> 93f30cc... Fix for bug 48832: Don't write a completely empty sieve script when purging. Instead write only a comment line
      * 
      * @param arguments
      * @return
@@ -839,8 +868,6 @@ public final class MailFilterServiceImpl implements MailFilterService {
         return nextUid;
     }
 
-    // --------------------------------------------------------------------------------------------------------------------- //
-
     private static final class Key {
 
         private final int cid;
